import os

from dotenv import load_dotenv
import mcp
from mcp.client.streamable_http import streamablehttp_client


# 加载 .env 文件中的环境变量
load_dotenv()


smithery_api_key = os.getenv('SMITHERY_API_KEY')
url = f"https://server.smithery.ai/@luochang212/card-magic-mcp/mcp?api_key={smithery_api_key}"


async def main():
    # Connect to the server using HTTP client
    async with streamablehttp_client(url) as (read_stream, write_stream, _):
        async with mcp.ClientSession(read_stream, write_stream) as session:
            # Initialize the connection
            await session.initialize()
            # List available tools
            tools_result = await session.list_tools()
            print(f"Available tools: {', '.join([t.name for t in tools_result.tools])}")


if __name__ == "__main__":
    import asyncio
    asyncio.run(main())



import itertools

from card_magic_mcp.magic import MagicMax


def factorial(n):
    """计算n的阶乘"""
    if n == 0 or n == 1:
        return 1
    else:
        return n * factorial(n-1)


def test_all():
    """测试所有牌组"""
    k = 4
    n = factorial(k) + k - 1
    magic = MagicMax(n, k)
    combinations = itertools.combinations(range(1, n+1), k)

    for combo in combinations:
        nums = list(combo)
        first_four, fifth_card = magic.reverse(magic.encoder(nums))
        guess_fifth_card = magic.decoder(first_four)
        assert fifth_card == guess_fifth_card



# -*- coding: utf-8 -*-

"""
Card Magic Agent
"""

from qwen_agent.agents import Assistant, ReActChat


class CMAgent:
    """Card Magic Agent"""

    def __init__(self, llm_cfg):
        self.llm_cfg = llm_cfg

    @staticmethod
    def create_tools():
        """获取工具列表"""
        return [
            {
                "mcpServers": {
                    "card_magic": {
                        "type": "stdio",
                        "command": "uvx",
                        "args": [
                            "--from",
                            "card-magic-mcp",
                            "card_magic_mcp"
                        ],
                    }
                }
            },
        ]

    def create_react_agent(self):
        """创建 ReActChat 模式的 Agent"""
        tools = self.create_tools()
        return ReActChat(
            llm=self.llm_cfg,
            name='卡牌魔术助手',
            description='使用 ReActChat 模式',
            system_message='',
            function_list=tools,
        )

    def create_assistant_agent(self):
        """创建 Assistant 模式的 Agent"""
        tools = self.create_tools()
        return Assistant(
            llm=self.llm_cfg,
            name='卡牌魔术助手',
            description='使用 Assistant 模式',
            system_message='',
            function_list=tools,
        )

    @staticmethod
    def ask(bot, messages: list) -> str:
        """使用指定的 bot 进行查询"""
        response = bot.run_nonstream(messages)
        message = response[-1].get('content').strip()
        return message


if __name__ == '__main__':
    # llm 配置
    llm_cfg = {
        'model': 'Qwen3-0.6B-FP8',
        'model_server': 'http://localhost:8000/v1',
        'api_key': 'token-kcgyrk',
        'generate_cfg': {
            'top_p': 0.95,
            'temperature': 0.6,
        }
    }

    # 实例化 CMAgent
    cma = CMAgent(llm_cfg)

    # 创建 Agent
    magic_agent = cma.create_react_agent()
    # magic_agent = cma.create_assistant_agent()

    # 变魔术
    query = "帮我编码 ♠2 ♠4 ♣2 ♦3 ♦7"
    msg = [
        {
            'role': 'user',
            'content': query
        }
    ]
    answer = cma.ask(magic_agent, msg)
    print(answer)



import nox


@nox.session
def tests(session):
    session.install('pytest')
    session.install('-e', '.')
    session.run('pytest')


@nox.session
def lint(session):
    session.install('flake8')
    session.install('flake8-import-order')
    session.run('flake8', '--import-order-style', 'google')
